==> cloud-5.0.0-rc2.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/aws_cloud/ec2/volume.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_VOLUME_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Volume',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '' },
          { type: 'select', labelName: 'Snapshot ID', name: 'snapshot_id',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/volume_snapshot_ids',
            defaultValue: '', required: true
          },
          { type: 'number', labelName: 'Size (GiB)', name: 'size', defaultValue: 1, required: true },
          { type: 'select', labelName: 'Volume type', name: 'volume_type',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/volume_types',
            defaultValue: '', required: true
          },
          { type: 'number', labelName: 'IOPS', name: 'iop', defaultValue: 1 },
          { type: 'select', labelName: 'Availability Zone', name: 'availability_zone',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/availability_zones',
            defaultValue: '', required: true
          },
          { type: 'default', labelName: 'KMS key ID', name: 'kms_key_id', defaultValue: '' },
          { type: 'boolean', labelName: 'Encrypted', name: 'encrypted', defaultValue: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Volume',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '' },
          { type: 'default', labelName: 'Volume ID', name: 'volume_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Instance ID', name: 'attachment_information', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Snapshot ID', name: 'snapshot_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Snapshot Name', name: 'snapshot_name', defaultValue: '', readOnly: true },
          { type: 'number', labelName: 'Size (GiB)', name: 'size', defaultValue: 1 },
          { type: 'select', labelName: 'Volume type', name: 'volume_type',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/volume_types',
            defaultValue: '', required: true
          },
          { type: 'number', labelName: 'IOPS', name: 'iop', defaultValue: 1 },
          { type: 'default', labelName: 'Availability Zone', name: 'availability_zone', defaultValue: '', readOnly: true },
          { type: 'boolean', labelName: 'Encrypted', name: 'encrypted', defaultValue: false, labels: ['On', 'Off'], readOnly: true },
          { type: 'default', labelName: 'Status', name: 'state', defaultValue: '', readOnly: true },
          { type: 'datetime', labelName: 'Created', name: 'created', defaultValue: 0, readOnly: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'attach',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to attach {{entityName}}: {{name}}?'
      },
      {
        type: 'panel',
        panelName: 'Volume Information',
        keyValueRecords: [
          { type: 'default', labelName: 'Volume id', name: 'volume_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Volume name', name: 'name', defaultValue: '', readOnly: true },
		      { type: 'default', labelName: 'Device Name', name: 'device_name', defaultValue: '' },
		      { type: 'select', labelName: 'Instance ID', name: 'instance_id',
		        url: '/cloud_dashboard/aws_cloud/{cloud_context}/aws_cloud_volume/{entity_id}/instances',
		        defaultValue: '', required: true
		      },
        ]
      },
    ],
    submitButtonLabel: 'Attach'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'detach',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to detach {{entityName}}: {{name}}?'
      },
      {
        type: 'panel',
        panelName: 'Volume Information',
        keyValueRecords: [
          { type: 'default', labelName: 'Volume ID', name: 'volume_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Volume name', name: 'name', defaultValue: '', readOnly: true },
          {
            type: 'join', labelName: 'Attached to instance', name: 'attachment_information', info: {
              entityTypeId: 'aws_cloud_instance',
              keyColumn: 'instance_id',
            }, defaultValue: '', readOnly: true
          },
        ]
      },
    ],
    submitButtonLabel: 'Detach'
  },
]

export default AWS_CLOUD_VOLUME_TEMPLATE;

==> cloud-5.1.1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/aws_cloud/ec2/volume.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_VOLUME_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Volume',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '' },
          { type: 'select', labelName: 'Snapshot ID', name: 'snapshot_id',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/volume_snapshot_ids',
            defaultValue: '', required: true
          },
          { type: 'number', labelName: 'Size (GiB)', name: 'size', defaultValue: 1, required: true },
          { type: 'select', labelName: 'Volume type', name: 'volume_type',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/volume_types',
            defaultValue: '', required: true
          },
          { type: 'number', labelName: 'IOPS', name: 'iop', defaultValue: 1 },
          { type: 'select', labelName: 'Availability Zone', name: 'availability_zone',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/availability_zones',
            defaultValue: '', required: true
          },
          { type: 'default', labelName: 'KMS key ID', name: 'kms_key_id', defaultValue: '' },
          { type: 'boolean', labelName: 'Encrypted', name: 'encrypted', defaultValue: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Volume',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '' },
          { type: 'default', labelName: 'Volume ID', name: 'volume_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Instance ID', name: 'attachment_information', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Snapshot ID', name: 'snapshot_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Snapshot name', name: 'snapshot_name', defaultValue: '', readOnly: true },
          { type: 'number', labelName: 'Size (GiB)', name: 'size', defaultValue: 1 },
          { type: 'select', labelName: 'Volume type', name: 'volume_type',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/volume_types',
            defaultValue: '', required: true
          },
          { type: 'number', labelName: 'IOPS', name: 'iop', defaultValue: 1 },
          { type: 'default', labelName: 'Availability Zone', name: 'availability_zone', defaultValue: '', readOnly: true },
          { type: 'boolean', labelName: 'Encrypted', name: 'encrypted', defaultValue: false, labels: ['On', 'Off'], readOnly: true },
          { type: 'default', labelName: 'Status', name: 'state', defaultValue: '', readOnly: true },
          { type: 'datetime', labelName: 'Created', name: 'created', defaultValue: 0, readOnly: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'attach',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to attach {{entityName}}: {{name}}?'
      },
      {
        type: 'panel',
        panelName: 'Volume Information',
        keyValueRecords: [
          { type: 'default', labelName: 'Volume id', name: 'volume_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Volume name', name: 'name', defaultValue: '', readOnly: true },
		      { type: 'default', labelName: 'Device name', name: 'device_name', defaultValue: '' },
		      { type: 'select', labelName: 'Instance ID', name: 'instance_id',
		        url: '/cloud_dashboard/aws_cloud/{cloud_context}/aws_cloud_volume/{entity_id}/instances',
		        defaultValue: '', required: true
		      },
        ]
      },
    ],
    submitButtonLabel: 'Attach'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'volume',
    actionType: 'detach',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to detach {{entityName}}: {{name}}?'
      },
      {
        type: 'panel',
        panelName: 'Volume Information',
        keyValueRecords: [
          { type: 'default', labelName: 'Volume ID', name: 'volume_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Volume name', name: 'name', defaultValue: '', readOnly: true },
          {
            type: 'join', labelName: 'Attached to instance', name: 'attachment_information', info: {
              entityTypeId: 'aws_cloud_instance',
              keyColumn: 'instance_id',
            }, defaultValue: '', readOnly: true
          },
        ]
      },
    ],
    submitButtonLabel: 'Detach'
  },
]

export default AWS_CLOUD_VOLUME_TEMPLATE;
